@@ -1,6 +1,7 @@
 from __future__ import absolute_import
 
 # import apis into api package
+from .authentication_exemptions_api import AuthenticationExemptionsApi
 from .capture_api import CaptureApi
 from .conversion_details_api import ConversionDetailsApi
 from .credit_api import CreditApi
@@ -11,6 +12,7 @@ from .instrument_identifier_api import InstrumentIdentifierApi
 from .key_generation_api import KeyGenerationApi
 from .net_fundings_api import NetFundingsApi
 from .notification_of_changes_api import NotificationOfChangesApi
+from .payer_authentication_api import PayerAuthenticationApi
 from .payment_batch_summaries_api import PaymentBatchSummariesApi
 from .payment_instrument_api import PaymentInstrumentApi
 from .payments_api import PaymentsApi
